# 030

|                                                                | 030-1wk080066v0w   |
|:---------------------------------------------------------------|:-------------------|
| bindTime                                                       | 1731684296339      |
| createTime                                                     | 0                  |
| deviceFeatureCode                                              | 1wk080066v0w       |
| deviceFeatureName                                              | DH3S80-DVW001      |
| deviceId                                                       | <redacted>         |
| deviceNickName                                                 | Dryer              |
| deviceTypeCode                                                 | 030                |
| deviceTypeName                                                 |                    |
| isShow                                                         | 1                  |
| offlineState                                                   | 1                  |
| puid                                                           | <redacted>         |
| role                                                           | 1                  |
| roomId                                                         | 6374407            |
| roomName                                                       | Waschküche         |
| seq                                                            | 0                  |
| statusList.Actions                                             | 0                  |
| statusList.AntiCrease                                          | 0                  |
| statusList.ApplicationPermissions                              | 3                  |
| statusList.Aromatherapy                                        | 0                  |
| statusList.Auxiliary_heat                                      | 0                  |
| statusList.Child_lock                                          | 0                  |
| statusList.Clean_Filter                                        | 0                  |
| statusList.Current_program_phase                               | 2                  |
| statusList.DelayEndTime_Hour                                   | 0                  |
| statusList.DelayEndTime_Minute                                 | 0                  |
| statusList.Door_status                                         | 2                  |
| statusList.DownLight_LightTime                                 | 0                  |
| statusList.Drum_Light                                          | 0                  |
| statusList.Dry_Level                                           | 1                  |
| statusList.Dry_Level_show                                      | 0                  |
| statusList.DryingWizzard_ClothesDryLevel                       | 0                  |
| statusList.DryingWizzard_ClothesDryLevel1                      | 0                  |
| statusList.DryingWizzard_ClothesDryTarget                      | 0                  |
| statusList.DryingWizzard_ClothesDryTarget1                     | 0                  |
| statusList.DryingWizzard_ClothesMaterialCharacteristics        | 0                  |
| statusList.DryingWizzard_ClothesMaterialCharacteristics_first  | 0                  |
| statusList.DryingWizzard_ClothesMaterialCharacteristics_second | 0                  |
| statusList.DryingWizzard_ClothesMaterialCharacteristics_third  | 0                  |
| statusList.DryingWizzard_ClothingType                          | 0                  |
| statusList.DryingWizzard_ClothingType_eighth                   | 0                  |
| statusList.DryingWizzard_ClothingType_eleventh                 | 0                  |
| statusList.DryingWizzard_ClothingType_fifth                    | 0                  |
| statusList.DryingWizzard_ClothingType_first                    | 0                  |
| statusList.DryingWizzard_ClothingType_fourth                   | 0                  |
| statusList.DryingWizzard_ClothingType_ninth                    | 0                  |
| statusList.DryingWizzard_ClothingType_second                   | 0                  |
| statusList.DryingWizzard_ClothingType_seventh                  | 0                  |
| statusList.DryingWizzard_ClothingType_sixth                    | 0                  |
| statusList.DryingWizzard_ClothingType_tenth                    | 0                  |
| statusList.DryingWizzard_ClothingType_third                    | 0                  |
| statusList.DryingWizzard_ClothingType_thirteenth               | 0                  |
| statusList.DryingWizzard_ClothingType_twelfth                  | 0                  |
| statusList.Electricit_consumption_decimal                      | 0                  |
| statusList.Electricit_consumption_int                          | 0                  |
| statusList.Favour_program_ID                                   | 0                  |
| statusList.Hard_pairing_commond                                | 0                  |
| statusList.Hard_pairing_status                                 | 1                  |
| statusList.Ion_Refresh                                         | 0                  |
| statusList.Iron_Dry_Time                                       | 0                  |
| statusList.Language                                            | 0                  |
| statusList.Natural_Dry                                         | 0                  |
| statusList.Night_Dry                                           | 0                  |
| statusList.Pause_AntiCrease_flag                               | 0                  |
| statusList.QuickerMode                                         | 0                  |
| statusList.ScreenSaverTime                                     | 0                  |
| statusList.Selected_program_ID                                 | 1                  |
| statusList.Selected_program_remaining_time_in_minutes          | 163                |
| statusList.Selected_program_total_running_time_in_minutes      | 163                |
| statusList.Selected_program_total_time_in_minutes              | 163                |
| statusList.Session_pairing_commond                             | 0                  |
| statusList.Session_pairing_states                              | 2                  |
| statusList.Sound_setting                                       | 0                  |
| statusList.StandardElectricitConsumption_int                   | 0                  |
| statusList.StandardElectricitconsumption_decimal               | 0                  |
| statusList.Steam                                               | 0                  |
| statusList.SteamEngineLackWaterState                           | 0                  |
| statusList.Store_Dry_Time                                      | 0                  |
| statusList.UV_Sterilization                                    | 0                  |
| statusList.Waterbox_Full                                       | 0                  |
| statusList.Wear_Dry_Time                                       | 0                  |
| statusList.currrent_dry_level_time                             | 0                  |
| statusList.daily_energy_kwh                                    | 0                  |
| statusList.default_dry_level                                   | 0                  |
| statusList.delay_close_dryer_time                              | 0                  |
| statusList.delay_time_hour_min                                 | 3                  |
| statusList.dry_time                                            | 3                  |
| statusList.drying_linkage_order                                | 0                  |
| statusList.drying_linkage_preheat_time                         | 0                  |
| statusList.drying_linkage_programid                            | 0                  |
| statusList.drying_washing_linkage_state                        | 0                  |
| statusList.energy                                              | 54                 |
| statusList.error_code                                          | 0                  |
| statusList.machine_status                                      | 1                  |
| statusList.mute                                                | 0                  |
| statusList.parse_lib_ver                                       | 20241030           |
| statusList.stoprunning_flag                                    | 0                  |
| statusList.support_preheat_state                               | 0                  |
| statusList.temperature                                         | 0                  |
| statusList.timezone                                            | 0                  |
| statusList.washing_machine_type                                | 0                  |
| statusList.washing_machine_type_kg                             | 18                 |
| useTime                                                        | 1731684296318      |
| wifiId                                                         | <redacted>         |

## Generated from

- [`030`](030-1wk080066v0w.json)
